#include <string.h>
#include "robapp.h"
#include "proto.h"
#include "menudef.h"

/****************************************************************************
   Method : AppCommand
   Parameters : win, the originating window
		id, the id of the command activated
		val, the option value returned by the command
		cType, the type of command activated
   Purpose : AppCommand processes any command not handled by the various
	     windows.
****************************************************************************/

void robustApp::AppCommand(vWindow* win, ItemVal id, ItemVal val,
			   CmdType cType)
{
  long pid;
  double a0,a1,a2;
  int curstate;
  switch (id) {
  case m_Open :
    if (!OpenFailureDataSet()) Message("Could not open file");
    break;

  case m_Reset :
    Reset();
    break;

  case m_Revert :
    Revert();
    break;

  case m_Save :
    SaveDataSet(((txtWin*)win)->data);
    break;

  case m_Fixed : 
    Smooth(1);
    if (Params.mtype != NotPresent) GenModel();
    break;

  case m_Lump :
    Smooth(2);
    if (Params.mtype != NotPresent) GenModel();   
    break;

  case m_LogModel :
    Params.mtype = Logarithmic;
    Params.modfunc = LogModel;
    Params.fitfunc = LogFit;
    Params.predfunc = LogPred;
    Params.statfunc = StatLogParms;
    strcpy(Params.mname,"Logarithmic");
    GenModel();
    break;

  case m_ExpModel :
    Params.mtype = Exponential;
    Params.modfunc = ExpModel;
    Params.fitfunc = ExpFit;
    Params.predfunc = ExpPred;
    Params.statfunc = StatExpParms;
    strcpy(Params.mname,"Exponential");
    GenModel();
    break;

    /*
  case m_LVModel :
    Params.mtype = Littlewood;
    Params.modfunc = LVModel;
    Params.fitfunc = LVFit;
    Params.predfunc = LVPred;
    GenModel();
    break;
    */

  case m_PowModel :
    Params.mtype = Power;
    Params.modfunc = PowModel;
    Params.fitfunc = PowFit;
    Params.predfunc = PowPred;
    Params.statfunc = NULL;
    strcpy(Params.mname,"Power");
    GenModel();
    break;

  case m_DlSModel :
    Params.mtype = DelayedS;
    Params.modfunc = DelSModel;
    Params.fitfunc = DelSFit;
    Params.predfunc = DelSPred;
    Params.statfunc = NULL;
    strcpy(Params.mname,"Delayed-S");
   GenModel();
    break;

  case m_StatExpModel :
    Params.mtype = Static;
    Params.modfunc = ExpModel;
    Params.statfunc = StatExpParms;
    Params.predfunc = ExpPred;
    strcpy(Params.mname,"Static Exponential");
    GenModel(1);
    break;

  case m_StatLogModel :
    Params.mtype = Static;
    Params.modfunc = LogModel;
    Params.statfunc = StatLogParms;
    Params.predfunc = LogPred;
    strcpy(Params.mname,"Static Logarithmic");
    GenModel(1);
    break;

  case m_CMBL :
    Params.mtype = Coverage;
    GenCovModel(1);
    break;
  case m_CMBR :
    Params.mtype = Coverage;
    GenCovModel(2);
    break;
  case m_CMPU :
    Params.mtype = Coverage;
    GenCovModel(3);
    break;
  case m_CMCU :
    Params.mtype = Coverage;
    GenCovModel(4);
    break;

  case m_StatMet :
    smdiag->ShowDialog("");
    break;

  case m_Help :
    hdiag->ShowDialog("");
    break;

  case m_Graph :
    if (OrgData || ModData) {
      EnsureWin(3);
      EnsureWin(7);
      FailMenus();
      if (Params.mtype != NotPresent) {
	win3->SetDataSet(Params.data2,Params.data1);
	win7->SetDataSet(Params.data2,Params.data1);
	MenuEntryState(m_ShowNum,1);
      }
      else {
	win3->SetDataSet(Params.data1,0);
	win7->SetDataSet(Params.data1,0);
	MenuEntryState(m_ShowNum,0);
      }
    }
    else if (CovData || CovModData) {
      EnsureWin(4);
      CovMenus();
      if (CovModData) {
	win4->SetDataSet(2);
	MenuEntryState(m_ShowNum,1);
      }
      else {
	win4->SetDataSet(1);
	MenuEntryState(m_ShowNum,0);
      }
    }
    break;
   
  case m_Recal :
    Params.recalibrate ^= 1;
    if (win1) win1->SetValue(m_Recal,Params.recalibrate,Checked);
    if (win2) win2->SetValue(m_Recal,Params.recalibrate,Checked);
    if (win3) win3->SetValue(m_Recal,Params.recalibrate,Checked);
    if (win7) win7->SetValue(m_Recal,Params.recalibrate,Checked);
    if (Params.mtype != NotPresent) GenModel();
    break;

  case m_Stable :
    Params.stabilize ^= 1;
    if (win1) win1->SetValue(m_Stable,Params.stabilize,Checked);
    if (win2) win2->SetValue(m_Stable,Params.stabilize,Checked);
    if (win3) win3->SetValue(m_Stable,Params.stabilize,Checked);
    if (win7) win7->SetValue(m_Recal,Params.recalibrate,Checked);
    if (Params.mtype != NotPresent) GenModel();
    break;

  case m_MLE :
    Params.fit_type = 1;
    if (win1) win1->SetValue(m_MLE,1,Checked);
    if (win2) win2->SetValue(m_MLE,1,Checked);
    if (win3) win3->SetValue(m_MLE,1,Checked);
    if (win7) win7->SetValue(m_MLE,1,Checked);
    if (win1) win1->SetValue(m_LSQ,0,Checked);
    if (win2) win2->SetValue(m_LSQ,0,Checked);
    if (win3) win3->SetValue(m_LSQ,0,Checked);
    if (win7) win7->SetValue(m_LSQ,0,Checked);
    if (Params.mtype != NotPresent) GenModel();
    break;

  case m_LSQ :
    Params.fit_type = 0;
    if (win1) win1->SetValue(m_MLE,0,Checked);
    if (win2) win2->SetValue(m_MLE,0,Checked);
    if (win3) win3->SetValue(m_MLE,0,Checked);
    if (win7) win7->SetValue(m_MLE,0,Checked);
    if (win1) win1->SetValue(m_LSQ,1,Checked);
    if (win2) win2->SetValue(m_LSQ,1,Checked);
    if (win3) win3->SetValue(m_LSQ,1,Checked);
    if (win7) win7->SetValue(m_LSQ,1,Checked);
    if (Params.mtype != NotPresent) GenModel();
    break;

  case m_ShowNum :
    ShowNumbers();
    break;

  case m_PTime :
    Predict(1);
    break;

  case m_PInten :
    Predict(2);
    break;

  case m_PCount :
    Predict(3);
    break;

  case m_About :
    myApp->About();
    break;
    /*
  case m_Manual :
#ifdef __UNIX__
      system("gv robust.ps &");
#endif
#ifdef __MSWIN__
      system("start robust.pdf");
#endif
  break;
  */
  case M_Exit :
    theApp->Exit();
    break;

  default :
    vApp::AppCommand(win,id,val,cType);
  }
}
