/*******************************************************************
  Module : coverage.cpp
  Contents : Definition of the CoverageDataPointClass and
  CoverageDataSet class
********************************************************************/
#include <fstream.h>
#include "datatype.h"

#define MAXPTS 50

double CoverageDataPoint::map(int i)
{
  if (i == 0) return faults;
  else if (i == 1) return block;
  else if (i == 2) return branch;
  else if (i == 3) return p_use;
  else if (i == 4) return c_use;
  return 0.0;
}
		     
/*************************************************************
  Constructor : CoverageDataSet
  Parameters : ns, the number of data points to be initiall
  allocated. Defaults to 0, no data points allocated.
**************************************************************/
CoverageDataSet::CoverageDataSet(int ns)
{
  if (ns) cov_data = new CoverageDataPoint[ns];
  else cov_data = NULL;

  avail[0] = 0;
  avail[1] = 0;
  avail[2] = 0;
  avail[3] = 0;
  avail[4] = 0;
  Size = ns;
}

/*************************************************************
  Destructor : CoverageDataSet
**************************************************************/
CoverageDataSet::~CoverageDataSet(void)
{
  if (cov_data) delete[] cov_data;
}

/**********************************************************************
  Method : OpenFile
  Parameters : fname, the name of the file to open
  Returns : 0 on failure, 1 on success
  Purpose : To read in a CDS formatted file (coverage data file)
**********************************************************************/

int CoverageDataSet::OpenFile(char* fname)
{
  int ncol;
  char temp[128];
  int remap[5];

  ifstream fin(fname);
  fin >> temp;
  if (strcmp(temp,"coverage")) return 0;

  FileName = new char[strlen(fname)+1];
  strcpy(FileName,fname);

  fin >> ncol;
  for (int cnt = 0; cnt < ncol; cnt++) {
    fin >> temp;
    if (!strcmp(temp,"faults")) {
      remap[cnt] = 0;
      avail[0] = 1;
    }
    else if (!strcmp(temp,"blocks")) {
      remap[cnt] = 1;
      avail[1] = 1;
    }
    else if (!strcmp(temp,"branches")) {
      remap[cnt] = 2;
      avail[2] = 1;
    }
    else if (!strcmp(temp,"p_uses")) {
      remap[cnt] = 3;
      avail[3] = 1;
    }
    else if (!strcmp(temp,"c_uses")) {
      remap[cnt] = 4;
      avail[4] = 1;
    }
  }
  
  Size = 0;
  if (cov_data) delete[] cov_data;
  cov_data = new CoverageDataPoint[MAXPTS];

  double dt;
  fin >> dt;
  while (!fin.eof()) {
    for (int cnt = 0; cnt < ncol; cnt++) {
      if (remap[cnt] == 0) 
	cov_data[Size].faults = dt;
      else if (remap[cnt] == 1)
	cov_data[Size].block = dt;
      else if (remap[cnt] == 2)
	cov_data[Size].branch = dt;
      else if (remap[cnt] == 3)
	cov_data[Size].p_use = dt;
      else if (remap[cnt] == 4)
	cov_data[Size].c_use = dt;
      fin >> dt;
    }
    Size++;
  }
  Shrink();
  return 1;
}

/**********************************************************************
  Method : Shrink
  Returns : 1 on success, 0 on failure (leaves data set unchanged)
  Purpose : Reduces the amount of memory used by the data set to only
  what is neccessary.
**********************************************************************/

int CoverageDataSet::Shrink(void)
{
  CoverageDataPoint* nd = new CoverageDataPoint[Size];
  if (!nd) return 0;
  for (int cnt = 0; cnt < Size; cnt++)
    nd[cnt] = cov_data[cnt];
  delete[] cov_data;
  cov_data = nd;
  return 1;
}
