/**************************************************************
  Module : help.cpp
  Contents : Definitions for methods of HelpEntry and HelpList.
  This module is the meat of the help system.
**************************************************************/
#include <fstream.h>
#include "help.h"

/**************************************************************
  Constructor : HelpEntry
**************************************************************/

HelpEntry::HelpEntry(void)
{
  name = NULL;
  for (int i = 0; i < MAX_LINES; i++) text[i] = NULL;
  numlines = 0;
}

/**************************************************************
  Destructor : HelpEntry
**************************************************************/

HelpEntry::~HelpEntry(void)
{
  delete name;
  for (int i = 0; i < MAX_LINES; i++)
    if (text[i]) delete text[i];
}

/****************************************************************
  Method : SetName
  Parameters : newname, the new name of the entry
  Purpose : Set the name of the help entry to newname.
**************************************************************/
void HelpEntry::SetName(char* newname)
{
  int len = strlen(newname);
  name = new char[len + 1];
  strcpy(name,newname);
}

/****************************************************************
  Method : AddLine
  Parameters : line, a line of text to add to the entry
  Purpose : To add a line of text to the help entry.
**************************************************************/
void HelpEntry::AddLine(char* line)
{
  if (numlines == MAX_LINES) return;
  int len = strlen(line); len++;
  text[numlines] = new char[len];
  strcpy(text[numlines],line);
  numlines++;
}

/**************************************************************
  Constructor : HelpList
**************************************************************/

HelpList::HelpList(void)
{
  data = NULL;
  next = NULL;
}

/**************************************************************
  Destructor : HelpList
**************************************************************/

HelpList::~HelpList(void)
{
  if (next) delete next;
  if (data) delete data;
}

/*****************************************************************
  Method : LoadTopics
  Parameters : fname, the name of the help file
  Purpose : LoadTopics reads in a help file and places its
  contents in the HelpList.
******************************************************************/

int HelpList::LoadTopics(char* fname)
{
  ifstream fin(fname);
  HelpEntry* topic;
  char input[100] = "";
  
  fin.getline(input,80,'\n');

  while (!fin.eof()) {
    while (input[0] != '@') fin >> input; //read to entry start
    topic = NewEntry();
    topic->SetName(&input[1]);
    
    fin.getline(input,80,'\n');   
    while (input[0] != '#') {
      topic->AddLine(input);
      fin.getline(input,80,'\n'); 
    }

    fin.getline(input,80,'\n');
  }
}  

/*******************************************************************
  Method : NewEntry
  Returns : A pointer to the data member of the new entry.
  Purpose : NewEntry allocates a new HelpEntry objects and appends
  it to the list of topics.
******************************************************************/

HelpEntry* HelpList::NewEntry(void)
{
  if (!data) {
    data = new HelpEntry;
    return data;
  }
  if (!next) next = new HelpList;
  return next->NewEntry();
}

/******************************************************************
  Operator : Array Index
  Purpose : To make HelpList perform like an array.
*******************************************************************/

HelpEntry* HelpList::operator[](int index)
{
  if (index < 0) return NULL;
  if (index == 0) return data;
  if (next) return (*next)[index-1];
  else return NULL;
}
