 /****************************************************************************
  Module : helpwin.cpp
  Contents : Definitions for the robust help window, and help topics
  dialog.
***************************************************************************/
#include <stdio.h>
#include "robapp.h"
#include "platform.h"

#define h_List 301
#define h_Topic 302
#define h_Close 303

//This is the array that declares the elements of helpDialog
static CommandObject cmdlist[] = {
  {C_List,h_List,0,"Help Topics",NULL,
   CA_NoNotify,isSens,NoFrame,0,0,0},
  {C_Button,h_Topic,h_Topic," Display Topic ",
   NoList,CA_None,isSens,0,0,h_List,HBUTTSIZE},
  {C_Button,h_Close,h_Close," Close ",NoList,CA_None,isSens,
   0,0,h_Topic,HBUTTSIZE},
  {C_EndOfList,0,0,0,0,CA_None,0,0,0,0}
};

/*******************************************************************
  Constructor : helpDialog
  Purpose : Create a help dialog and read in help topics
******************************************************************/
helpDialog::helpDialog(vApp* parent)
  : vDialog(parent,0,"Help Topics")
{
  int i = 0;

  topics.LoadTopics("robust.hlp");
  while (topics[i]) {
    list[i] = topics[i]->name;
    i++;
  }
  list[i] = NULL;
  
  cmdlist[0].itemList = (void*) list;
  AddDialogCmds(cmdlist); 
}

/************************************************************************
  Method : DialogCommand
  Parameters : id, the button pushed
               val, the value of the button pushed
	       cType, nothing really
  Purpose : This is a callback, called by the V library. It handels
  dialog actions.
**************************************************************************/

void helpDialog::DialogCommand(ItemVal id, ItemVal val, CmdType cType)
{
  int sub;

  switch(id) {
  case h_Topic :
    sub = GetValue(h_List);
    if (sub < 0) return;
    myApp->EnsureWin(5);
    myApp->win5->SetTopic(topics[sub]);
    break;
  case h_Close :
    CloseDialog();
    break;
  default :
    vDialog::DialogCommand(id,val,cType);
  }
}

/****************************************************************************
  Constructor: helpWin
  Parameters: name, the name of the window
  h, the height of the window
  w, the width of the window
*****************************************************************************/

helpWin::helpWin(char* name, int h, int w)
  : vCmdWindow(name,w,h)
{
  tp = new helpPane;
  AddPane(tp);
  ShowWindow(); 
  vFont myfont(vfSerif,FntSize);
  tp->SetFont(myfont);
}

/*******************************************************************
  Method : CloseWin
  Purpose : To notify robust that a window has been closed, and that
  the pointer to it is no longer valid.
*******************************************************************/

void helpWin::CloseWin(void)
{
  myApp->CloseNotify(this);
  vCmdWindow::CloseWin();
}

/*************************************************************************
  Method : SetTopic
  Parameters : topic, the topic to be displayed
  Purpose : SetTopic displays a help topic in the helpp window
************************************************************************/

void helpWin::SetTopic(HelpEntry* topic)
{
  if (!topic) return;
  tp->Clear();
  tp->SetTopic(topic);
  SetTitle(topic->name);
}

/**************************************************************
  Constructor : helpPane
*************************************************************/

helpPane::helpPane(void)
{
  topic = NULL;
}

/****************************************************************
  Method : SetTopic
  Parameters : subject, the topic to be displayed.
  Purpose : To set the help text to be displayed.
****************************************************************/

void helpPane::SetTopic(HelpEntry* subject)
{
  topic = subject;
  ShowDataSet(0);
}

/****************************************************
  Method : ShowDataSet
  Purpsoe : To display help text.
***************************************************/
void helpPane::ShowDataSet(int)
{
  if (!topic) return;
  char buf[102];
  for (int i = 0; i < topic->numlines; i++) {
    sprintf(buf,"%s\n",topic->text[i]);
    DrawText(buf);
  }
}
