/****************************************************************************
  Module: Menudef.cpp
  Contents: Menu definitions for the robust menu system.
****************************************************************************/
#include <v/vkeys.h>
#include "menudef.h"

static vMenu SmoothMenu[] = {
	{"&Fixed Smoothing", m_Fixed, isSens, notChk, noKeyLbl,vk_F3, noSub},
	{"&Lump Smoothing", m_Lump, isSens, notChk, noKeyLbl,vk_F4, noSub},
	{"-", M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"&Recalibrate", m_Recal, isSens, notChk, noKeyLbl,vk_F5, noSub},
	{"&Stabilize",m_Stable,isSens, notChk,noKeyLbl,vk_F6,noSub},
	{"-", M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"&MLE Estimation", m_MLE, isSens, notChk, noKeyLbl,vk_F7, noSub},
	{"LS&Q Estimation",m_LSQ,isSens, notChk,noKeyLbl,vk_F8,noSub},

	{NULL}
};

static vMenu ModelsMenu[] = {
	{"&Exponential", m_ExpModel, isSens, notChk, noKeyLbl, 'e', noSub},
	{"&Logarithmic", m_LogModel, isSens, notChk, noKeyLbl, 'l', noSub},
	{"&Power", m_PowModel, isSens, notChk, noKeyLbl, 'p', noSub},
	{"&Delayed-S", m_DlSModel, isSens, notChk, noKeyLbl, 's', noSub},
//	{"&Littlewood-Verral", m_LVModel, isSens, notChk, noKeyLbl, noKey, noSub},
	{"-", M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"&Static Exponential", m_StatExpModel, isSens, notChk, noKeyLbl, noKey, noSub},
	{"&Static Logarithmic", m_StatLogModel, isSens, notChk, noKeyLbl, noKey, noSub},
	{"-", M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"B&lock Coverage", m_CMBL, isSens, notChk, noKeyLbl, noKey, noSub},
	{"B&ranch Coverage", m_CMBR, isSens, notChk, noKeyLbl, noKey, noSub},
	{"&P-Use Coverage",m_CMPU,isSens,notChk,noKeyLbl, noKey,noSub},
	{"C-&Use Coverage", m_CMCU, isSens, notChk, noKeyLbl, noKey, noSub},
	{NULL}
};

static vMenu ViewMenu[] = {
	{"&Graph", m_Graph, isSens, notChk, noKeyLbl, 'g', noSub},
	{"&Model Information", m_ShowNum, isSens, notChk, noKeyLbl, 'i', noSub},
	{"&Static Metrics", m_StatMet, isSens, notChk, noKeyLbl, vk_F2, noSub},
	{"-",M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"&Predict On Time", m_PTime, isSens, notChk, noKeyLbl, noKey, noSub},
	{"&Predict On Intensity",m_PInten,isSens,notChk,noKeyLbl, noKey,noSub},
	{"&Predict On Failure Count", m_PCount, isSens, notChk, noKeyLbl, noKey, noSub},
	{NULL}
};

static vMenu FileMenu[] = {
 	{"&Open", m_Open, isSens, notChk, noKeyLbl, 'f', noSub},
	{"&Save", m_Save, isSens, notChk, noKeyLbl, 's', noSub},
	{"Re&vert", m_Revert, isSens, notChk, noKeyLbl, 'v', noSub},
	{"&Reset", m_Reset, isSens, notChk, noKeyLbl, 'r', noSub},
	{"-", M_Line, notSens, notChk, noKeyLbl, noKey, noSub},
	{"&Exit", M_Exit, isSens, notChk, noKeyLbl, 'q', noSub},
	{NULL}
};

static vMenu HelpMenu[] = {
  {"&Help",m_Help,isSens,notChk,noKeyLbl,vk_F1,noSub},
//	{"&Manual", m_Manual, isSens, notChk, noKeyLbl,noKey, noSub},
	{"&About", m_About, isSens, notChk, noKeyLbl,'A', noSub},
	{NULL}
};

static vMenu MainMenu[] = {
	{"&File", M_File, isSens, notUsed, noKeyLbl, 'F', &FileMenu[0]},
	{"&Query", m_ViewMenu, isSens, notUsed, noKeyLbl, 'Q',&ViewMenu[0]},
	{"&Enhance", m_SmoothMenu, isSens, notUsed, noKeyLbl,'E',&SmoothMenu[0]},
	{"&Models", m_ModelsMenu, isSens, notUsed, noKeyLbl,'M',&ModelsMenu[0]},
	{"&Help", m_HelpMenu, isSens, notUsed, noKeyLbl,'H',&HelpMenu[0]},
	{NULL}
};
