/****************************************************************************
  Module: Numsel.cpp
  Contents: Method definition for the numSelDiag, a class to allow the user to
  pick a number.
*****************************************************************************/

#include <stdio.h> //for sprintf
#include "numsel.h"
#include "platform.h"

//This is the list of dialog box objects. It must be declared as static, since
//it is accessed both by this code and the toolkit, and can not go out of scope
//as long as the dialog exists. This is the list that controls the dialog box
//apperance.
static CommandObject cmdlist[] = {
  {C_Label, m_Space1,0,"", NoList, CA_MainMsg, isSens, NoFrame},
  {C_Label, m_SldVal, 0, "", NoList, CA_NoSpace, isSens, NoFrame, m_Space1},
  {C_Slider, m_Slide, 50, "", NoList, CA_Horizontal | R_Slider, 
   isSens, NoFrame, 0, m_SldVal},
  {C_Button, M_OK, M_OK, " Ok ", NoList, CA_DefaultButton, 
   isSens, NoFrame,0,m_Slide,SBUTTSIZE},
  {C_EndOfList,0,0,0,0,CA_None,0,0}
};

/*****************************************************************************
  Constructor: intSelDiag
  Parameters: title, the title of the dialog box
  low, the lowest value the user can select
  high, the highest value the user can select
  def, the default value of the selector
*****************************************************************************/

numSelDiag::numSelDiag(char* title) : vModalDialog(theApp,title)
{
  cmdlist[1].title = nstr;
}

/****************************************************************************
  Method: DialogCommand
  Parameters: id, the id of the command to be processed
  val, on option value returned by the command
  cType, the type of command to be processed
  Purpose: DialogCommand calls its parent to perform default processing on
  incoming commands, then does any special processing neccassary
  for the dialog box. At the moment, it simply sets the value of
  slider and the number it displays.
*****************************************************************************/

void numSelDiag::DialogCommand(ItemVal id, ItemVal retval, CmdType cType)
{
  vModalDialog::DialogCommand(id,retval,cType);
  switch(id) {
  case m_Slide :
    SetStringValue(retval);
    break;
  }
}

/*****************************************************************************
  Constructor: intSelDiag
  Parameters: title, the title of the dialog box
  low, the lowest value the user can select
  high, the highest value the user can select
  def, the default value of the selector
*****************************************************************************/

intSelDiag::intSelDiag(char* title, int low, int high, int def) :
  numSelDiag(title)
{
  Low = low;
  High = high;
  int t = Num2Slide(def);
  SetStringValue(t);
  cmdlist[2].retVal = t;   
  AddDialogCmds(cmdlist);
}

/****************************************************************************
  Constructor: fltSelDiag
  Parameters: title, the title of the dialog box
  low, the lowest value the user can select
  high, the highest value the user can select
  def, the default value of the selector
*****************************************************************************/

fltSelDiag::fltSelDiag(char* title, float low, float high, float def) :
  numSelDiag(title)
{
  Low = low;
  High = high;
  SetStringValue(Num2Slide(def));
  AddDialogCmds(cmdlist);
}

/****************************************************************************
  Method: Slide2Num
  Parameters: val, the number to map
  Returns: The number the user actually selected.
  Purpose: Slide2Num recieves a number from 0 to 100 inclusive, and transforms
  it into a number in the specified range. It is used to determine the
  value of the number selected from the slider.
***************************************************************************/

int intSelDiag::Slide2Num(int val)
{
  if (val == 100) return High;
  if (!val) return Low;
  return int((float(val) / 100.0) * float(High - Low + 1) + Low);
}

float fltSelDiag::Slide2Num(int val)
{
  if (val == 100) return High;
  if (!val) return Low;
  return (float(val) / 100.0) * (High - Low) + Low;
}

/*****************************************************************************
  Method: Num2Slide
  Parameters: val, the number the user selected
  Returns: The position of the slide
  Purpose: Num2Slide takes a number between Low and High and computes the
  point on the slide that corresponds to that number.
*****************************************************************************/
int intSelDiag::Num2Slide(int val)
{
  if (val >= High) return 100;
  if (val <= Low) return 0;
  else return int((val - Low) * (100.0 / float(High - Low + 1)));
}

int fltSelDiag::Num2Slide(float val)
{
  if (val >= High) return 100;
  if (val <= Low) return 0;
  else return int((val - Low) * (100.0 / (High - Low)));
}

/****************************************************************************
  Method: SetStringValue
  Parameters: val, the value of the slider
  Purpose: To show the exact value selected by the user. Used by parent class.
*****************************************************************************/

void intSelDiag::SetStringValue(int val)
{
  sprintf(nstr,"%d",Slide2Num(val));
  SetString(m_SldVal,nstr);
}

void fltSelDiag::SetStringValue(int val)
{
  sprintf(nstr,"%.2f",Slide2Num(val));
  SetString(m_SldVal,nstr);
}

/****************************************************************************
  Method: GetNum
  Parameters: msg, the message to be displayed in the dialog box
  Returns: The number selected by the user
  Purpose: GetNum displays the dialog box and returns the number selected by
  the user.
****************************************************************************/

int intSelDiag::GetNum(char* msg)
{
  int tmp;
  ShowModalDialog(msg,tmp);
  return Slide2Num(GetValue(m_Slide));
}

float fltSelDiag::GetNum(char* msg)
{
  int tmp;
  ShowModalDialog(msg,tmp);
  return Slide2Num(GetValue(m_Slide));
}
