/*****************************************************************
  Module : pdiag.cpp
  Contents : Definitions for the PredDialog and Pred2Dialog
  dialog box classes. PredDiag querys the user for their
  prediction, and Pred2Diag displays the information
******************************************************************/
#include <stdio.h>
#include "robapp.h"
#include "pdiag.h"
#include "platform.h"

//Labels for dialog box elements
#define m_mt 401
#define m_cr1 402
#define m_cr2 403
#define m_in 404
#define m_lbl1 405
#define m_lbl2 406
#define m_lbl3 407
#define m_cv 408
#define m_lbl4 409
#define m_first 410
#define m_second 411
#define m_res1 412
#define m_res2 413

//Definition of the PredDialog dialog box
static CommandObject cmdlist[] = {
  {C_Label,m_mt,0,NULL,NoList,CA_None,isSens,NoFrame,0,0,0}, //model name 0
  {C_Label,m_lbl1,0,"Current",NoList,CA_None,isSens,NoFrame,0,m_mt,0}, //1
  {C_Label,m_cr1,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,m_lbl1,m_mt,0}, //2
  {C_Label,m_lbl4,0,"is:",NoList,CA_None,isSens,NoFrame,m_cr1,m_mt,0}, //3
  {C_Label,m_cv,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,0,m_lbl1,0}, //4
  
  {C_Label,m_lbl2,0,"Predict when",NoList,CA_None,isSens,NoFrame,0,m_cv,0},
  {C_Label,m_cr2,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,m_lbl2,m_cv,0},//6
  {C_Label,m_lbl3,0,"is:",NoList,CA_None,isSens,NoFrame,m_cr2,m_cv,0},//7
  {C_TextIn,m_in,0,NULL,NoList,CA_None,isSens,NoFrame,0,m_lbl3,0}, //8
  
  {C_Button,M_OK,M_OK," OK ",NoList,CA_None,isSens,NoFrame,0,m_in,SBUTTSIZE},
  {C_EndOfList,0,0,0,0,CA_None,0,0,0} //10
};

/**************************************************************************
  Constructor : PredDialog
  Purpose : Creates a prediction query dialog box and fills in the
  appropriate information.
*************************************************************************/

PredDialog::PredDialog(int predon)
  : vModalDialog(myApp,"Prediction")
{
  switch (myApp->Params.mtype) {
  case Exponential : 
    sprintf(buf[0],"Exponential Model");
    break;
  case Logarithmic :
    sprintf(buf[0],"Logarithmic Model");
    break;
  case Power :
    sprintf(buf[0],"Power Model");
    break;
  case DelayedS :
    sprintf(buf[0],"Delayed S Model");
    break;
  case Littlewood :
    sprintf(buf[0],"Littlewood-Verral Model");
    break;
  case Static :
    sprintf(buf[0],"Static Model");
    break;
  case User_Defined :
    sprintf(buf[0],"User Model");
    break;
  }
  
  FailureDataSet* tmp = myApp->ModData;
  switch(predon) {
  case 1 :
    sprintf(buf[1],"time");
    sprintf(buf[2],"%.4f",tmp->Failure_Data[tmp->Size - 1].time);
    break;
  case 2 :
    sprintf(buf[1],"intensity");
    sprintf(buf[2],"%.7f",tmp->Failure_Data[tmp->Size - 1].intensity);
    break;
  case 3 :
    sprintf(buf[1],"failure count");
    sprintf(buf[2],"%.2f",tmp->Failure_Data[tmp->Size - 1].count);
    break;
  }
  cmdlist[0].title = buf[0];
  cmdlist[2].title = buf[1];
  cmdlist[4].title = buf[2];
  cmdlist[6].title = buf[1];
  value = 0.0;

  AddDialogCmds(cmdlist);
}

/*****************************************************************************
  Method : DialogCommand
a  Purpose : To set the value of the dialog box when the ok button is
clicked.
******************************************************************************/

void PredDialog::DialogCommand(ItemVal id, ItemVal val, CmdType cType)
{
  char temp[32];
  if (id == M_OK) { 
    GetTextIn(m_in,temp,31);
    value = atof(temp);
  }
  
  vDialog::DialogCommand(id,val,cType);
}

//Definition of the dialog box displayed by Pred2Dialog
static CommandObject cmdlist2[] = {
  {C_Label,m_mt,0,NULL,NoList,CA_None,isSens,NoFrame,0,0,0}, //model name 0
  {C_Label,m_lbl1,0,"When",NoList,CA_None,isSens,NoFrame,0,m_mt,0}, //1
  {C_Label,m_cr1,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,m_lbl1,m_mt,0}, //2
  {C_Label,m_lbl4,0,"is:",NoList,CA_None,isSens,NoFrame,m_cr1,m_mt,0}, //3
  {C_Label,m_cv,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,0,m_lbl1,0}, //4
 
  {C_Label,m_first,0,NULL,NoList,CA_None,isSens,NoFrame,0,m_cv,0}, //5
  {C_Label,m_lbl2,0,"will be",NoList,CA_None,isSens,NoFrame,m_first,m_cv,0},
  {C_Label,m_res1,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,m_lbl2,m_cv,0},//7
  {C_Label,m_second,0,NULL,NoList,CA_None,isSens,NoFrame,0,m_first,0}, //8
  {C_Label,m_lbl3,0,"will be",NoList,CA_None,isSens,NoFrame,m_second,m_lbl2,0},
  {C_Label,m_res2,0,"FILLERXX",NoList,CA_None,isSens,NoFrame,m_lbl3,m_res1,0},

  {C_Button,M_OK,M_OK," OK ",NoList,CA_None,isSens,NoFrame,0,m_res2,SBUTTSIZE},
  {C_EndOfList,0,0,0,0,CA_None,0,0,0} //10
};

/**************************************************************************
  Constructor : Pred2Dialog
  Purpose : Creates a prediction answer dialog box and fills in the
  appropriate information.
*************************************************************************/
Pred2Dialog::Pred2Dialog(int predon,double value)
  : vModalDialog(myApp,"Prediction")
{
  switch (myApp->Params.mtype) {
  case Exponential : 
    sprintf(buf[0],"Exponential Model");
    break;
  case Logarithmic :
    sprintf(buf[0],"Logarithmic Model");
    break;
  case Power :
    sprintf(buf[0],"Power Model");
    break;
  case DelayedS :
    sprintf(buf[0],"Delayed S Model");
    break;
  case Littlewood :
    sprintf(buf[0],"Littlewood-Verral Model");
    break;
  case Static :
    sprintf(buf[0],"Static Model");
    break;
  case User_Defined :
    sprintf(buf[0],"User Model");
    break;
  }
  
  FailureDataSet* tmp = myApp->ModData;

  double time = 0.0;
  double lambda = 0.0;
  double mu = 0.0;
  int r1,r2;

  switch(predon) {
  case 1 :
    sprintf(buf[1],"time");
    sprintf(buf[3],"Intensity");
    sprintf(buf[4],"Failure Count");
    time = value;
    r1 = 6;
    r2 = 7;
    break;
  case 2 :
    sprintf(buf[1],"intensity");
    sprintf(buf[3],"Time");
    sprintf(buf[4],"Failure Count");
    lambda = value;
    if (myApp->Params.recalibrated) lambda += myApp->Params.intenbias;
    r1 = 5;
    r2 = 7;
    break;
  case 3 :
    sprintf(buf[1],"failure count");
    sprintf(buf[3],"Time");
    sprintf(buf[4],"Intensity");
    mu = value;
    if (myApp->Params.recalibrated) mu += myApp->Params.cntbias;
    r1 = 5;
    r2 = 6;
    break;    
  }
  sprintf(buf[2],"%.7f",value);

  myApp->Params.predfunc(myApp->Params.beta0,myApp->Params.beta1,
			 time,lambda,mu);
  if (myApp->Params.recalibrated) {
    lambda -= myApp->Params.intenbias;
    mu -= myApp->Params.cntbias;
  }

  sprintf(buf[5],"%.3f",time);
  sprintf(buf[6],"%.7f",lambda);
  sprintf(buf[7],"%.2f",mu);

  cmdlist2[0].title = buf[0];
  cmdlist2[2].title = buf[1];
  cmdlist2[4].title = buf[2];
  cmdlist2[5].title = buf[3];
  cmdlist2[8].title = buf[4];
  cmdlist2[7].title = buf[r1];
  cmdlist2[10].title = buf[r2];

  AddDialogCmds(cmdlist2);
}
