/***************************************************************************
Model : Proto.h
Contents : Function prototypes used by robust
****************************************************************************/
#ifndef PROTOTYPES
#define PROTOTYPES
#include "datatype.h"


#define LSQ 0
#define MLE 1

//Prototypes for models, taken from models.cpp
void LogModel(double, double, double, double&, double&);
void ExpModel(double, double, double, double&, double&);
void PowModel(double, double, double, double&, double&);
void DelSModel(double, double, double, double&, double&);
void LVModel(double, double, double, double&, double&);

//Prototypes for prediction functions
void LogPred(double, double, double&, double&, double&);
void ExpPred(double, double, double&, double&, double&);
void PowPred(double, double, double&, double&, double&);
void DelSPred(double, double, double&, double&, double&);
void LVPred(double, double, double&, double&, double&);

//Prototypes for fitting functions
int LogFit(FailureDataSet*, double&, double&,int=1);
int ExpFit(FailureDataSet*, double&, double&,int=1);
int PowFit(FailureDataSet*, double&, double&,int=1);
int DelSFit(FailureDataSet*, double&, double&,int=1);
int LVFit(FailureDataSet*, double&, double&,int=1);

//Prototypes for static modeling functions
int StatExpParms(StaticMetrics,double&, double&);
int StatLogParms(StaticMetrics,double&, double&);
FailureDataSet* StatStub(StaticMetrics);

//Prototypes for enhancement functions, from enhance.cpp
FailureDataSet* FixedGrouping(FailureDataSet*, int);
FailureDataSet* FixedGrouping2(FailureDataSet*, int);
FailureDataSet* LumpGrouping(FailureDataSet*,int = 2);
void ModelBias(FailureDataSet*, FailureDataSet*,double&, double&);
void Recalibrate(FailureDataSet*, FailureDataSet*,
		 void (*)(double, double, double, double&, double&),
		 int (*)(FailureDataSet*, double&, double&,int),double,int);


//Prototype for modeling functions
FailureDataSet* Model(FailureDataSet*, double, double,
		      void (*func)(double,double,double,double&,double&));
int ExpandModel(FailureDataSet*, FailureDataSet*&, double, double,
		void (*func)(double,double,double,double&,double&));
void ShrinkModel(FailureDataSet*& fd);
double MRE(FailureDataSet*,
	   void (*func)(double,double,double,double&,double&),
	   int (*fitfunc)(FailureDataSet*, double&, double&,int),int = 0,
	   StaticMetrics* = NULL,
	   int (*)(StaticMetrics,double&,double&) = NULL,int=1);
double MPE(FailureDataSet*,
	   void (*func)(double,double,double,double&,double&),
	   int (*fitfunc)(FailureDataSet*, double&, double&,int),int = 0,
	   StaticMetrics* = NULL,
	   int (*)(StaticMetrics,double&,double&) = NULL,int=1);
int ParmFit(FailureDataSet*, double&, double&,
	     void (*evalfunc)(float,float[],float*,float[],int));
void LeastSquares(double[],double[], int, double&, double&);
double LaplaceFactor(FailureDataSet*);

//Prototypes for coverage modeling
void CovFit(CoverageDataSet*,int,double&, double&, double&);
CoverageDataSet* CoverageModel(int, double, double, double);
double chitest(CoverageDataSet*, CoverageDataSet*);
#endif
