/*****************************************************************************
  Module : Robapp.h
  Contents : Class definition for robustApp, the main application class.
*****************************************************************************/

#ifndef ROBAPP_H
#define ROBAPP_H

#include <v/vapp.h>
#include <v/vcmdwin.h>
#include <v/vawinfo.h>
#include <v/vnotice.h>

#include "txtwin.h"
#include "graph.h"
#include "covgraph.h"
#include "about.h"
#include "statdiag.h"
#include "helpwin.h"
#include "modinfo.h"
#include "datatype.h"

#define OrigData 1 //These four macros tell which type of data a window holds
#define ModelData 2
#define SmoothData 3
#define CoverData 4
#define CoverModelData 5

/*****************************************************************************
  Class: robustApp
  Purpose: This is main application class from the program. It handles basic
  processing for the system and processes command that the various
  windows do not.
****************************************************************************/

class robustApp : public vApp
{
  friend int AppMain(int, char**); //Entry point needs access
  void FailMenus(void);
  void CovMenus(void);
  void StartMenus(void);
  void MenuEntryState(ItemVal,ItemVal);
  void SetTitle(char*);

public:
  robustApp(void);
  virtual ~robustApp(void);
  //NewAppWin creates and registers a new window with the window system
  virtual vWindow* NewAppWin(vWindow*, char*, int, int, vAppWinInfo*);
  //AppCommand handels all commands given to robust

  void AppCommand(vWindow*, ItemVal, ItemVal, CmdType);
 
  void About(void); //Displays the about dialog box
  //Reads in and displays a set of failure data
  int OpenFailureDataSet(char* = NULL); 
  void CloseNotify(vCmdWindow*); //Called when a window is closed
  void ShowNumbers(void); //Displays the model info dialog box
  void Predict(int); //Allows user to request and display predictions
  void GenModel(int = 0); //Generates a new SRGM model
  void GenCovModel(int); //Generates a new coverage model
  void Smooth(int); //Performs smoothing on a data set
  void EnsureWin(int); //Ensures that the window is question is open
  void Revert(void);
  void Reset(void);
  void SaveDataSet(int);

  Parameters Params; //Saves state information about robust
  StaticMetrics StatMet; //The set of static metrics currently in use
  FailureDataSet* OrgData; //Original data set being worked with
  FailureDataSet* SmthData; //Smoothed data set being worked with
  FailureDataSet* ModData; //Model being examined
  CoverageDataSet* CovData; //Coverage data set being used
  CoverageDataSet* CovModData; //Coverage model being used

  vNoticeDialog* vn; //Dialog box for quicky messages
  StatMetDiag* smdiag; //Dialog box for static metrics information
  helpDialog* hdiag; //Dialog box for help system
  AboutBox* about;
  txtWin* win1; //Window for displaying original/smoothed data
  txtWin* win2; //Window for displaying model data
  grphWin* win3; //Window for displaying SRGM graph
  covgrphWin* win4; //Window for displaying coverage graph
  helpWin* win5; //Window for help topics
  infoWin* win6; //Window for model information
  grphMuWin* win7;
};

//Handy macro for accessing global pointer to application class
#define myApp ((robustApp*)theApp)
//Macro for displaying a quicky message
#define Message(x) ((robustApp*)theApp)->vn->Notice(x)
//Debug macro for displaying a number
#define NumMessage(x) char _bogus_[16];sprintf(_bogus_,"%.4f",float(x));((robustApp*)theApp)->vn->Notice(_bogus_)

#endif





