/****************************************************************************
  Module: Statdiag.cpp
  Contents: Method definitions for the StatMetDiag class.
****************************************************************************/
#include <stdio.h> //sprintf
#include <math.h> //atof
#include <v/vnotice.h>
#include "robapp.h"
#include "statdiag.h"
#include "stdgdef.h"
#include "proto.h"

/****************************************************************************
  Constructor: StatMetDiag
  Parameters: parent, the parent application
****************************************************************************/
StatMetDiag::StatMetDiag(vApp* parent)
  : vDialog(parent,0,"Static Metrics")
{
  cmdlist[10].title = buf[0];
  cmdlist[14].title = buf[5];
  cmdlist[22].title = buf[1];
  cmdlist[24].title = buf[4];
  cmdlist[26].title = buf[3];
  cmdlist[30].title = buf[2];
  cmdlist[28].title = buf[6];
  cmdlist[37].title = buf[7];
  cmdlist[39].title = buf[8];
  cmdlist[41].title = buf[9];
  cmdlist[43].title = buf[10];

  Data2Box();
  AddDialogCmds(cmdlist);
}

/******************************************************************************
  Method: DialogCommand
  Parameters: id, the id of the command being proccessed
  val, an option value returned by the command
  cType, the type of command
  Purpose: DialogCommand processes all commands sent to the dialog box.
*****************************************************************************/

void StatMetDiag::DialogCommand(ItemVal id, ItemVal val, CmdType cType)
{
  char buf[12];
  static vNoticeDialog vn(this);
  
  switch(id) {	
  case m_Struct :
    sprintf(buf,"%4d",val);
    SetString(m_StrctNum,buf);
    break;
  case m_Set :
    if(!Box2Data())
      vn.Notice("Error: Bad data entered");
    SetParameters();
    break;
  case m_Hide :
    if(!Box2Data())
      vn.Notice("Error: Bad data entered");
    else
      CloseDialog();
         break;
  }
  vDialog::DialogCommand(id,val,cType);
}


/*********************************************************
  Method : Data2Box
  Purpose : To copy the values stored in the global static
  parameters structure into the dialog box.
***********************************************************/

void StatMetDiag::Data2Box(void)
{
  int tmp;

  sprintf(buf[0],"%.2f",myApp->StatMet.Constant);
  sprintf(buf[1],"%.2f",myApp->StatMet.CPUrate);
  sprintf(buf[2],"%.2f",myApp->StatMet.Size);
  sprintf(buf[3],"%.2f",myApp->StatMet.Instructions);
  sprintf(buf[4],"%.2f",myApp->StatMet.Alpha);
  sprintf(buf[6],"%.2f",myApp->StatMet.Time);
  SetValue(m_EstType,myApp->StatMet.EstType,Checked);

  sprintf(buf[5],"%d",int((myApp->StatMet.Structure - 1.0) / 0.4 * 100));
  SetValue(m_Struct,int((myApp->StatMet.Structure - 1.0) / 0.4 * 100),Value);

  if (myApp->StatMet.Maturity == 1.5) tmp = 0;
  else if (myApp->StatMet.Maturity == 1.0) tmp = 1;
  else if (myApp->StatMet.Maturity == 0.4) tmp = 2;
  else if (myApp->StatMet.Maturity == 0.1) tmp = 3;
  else if (myApp->StatMet.Maturity == 0.05) tmp = 4;
  SetValue(m_Mature,tmp,Value);
  
  if (myApp->StatMet.Prog_Team == 0.4) tmp = 0;
  else if (myApp->StatMet.Prog_Team == 1.0) tmp = 1;
  else tmp = 2;
  SetValue(m_Team,tmp,Value);

  if (myApp->StatMet.Phase == 4.0) tmp = 0;
  else if (myApp->StatMet.Phase == 2.5) tmp = 1;
  else if (myApp->StatMet.Phase == 1.0) tmp = 2;
  else if (myApp->StatMet.Phase == 0.35) tmp = 3;
  SetValue(m_Phase,tmp,Value);

  SetParameters();
  return;
}

void StatMetDiag::SetParameters(void)
{
  double eb0,eb1,lb0,lb1;
  StatExpParms(myApp->StatMet,eb0,eb1);
  StatLogParms(myApp->StatMet,lb0,lb1);
  sprintf(buf[7],"%3.7f",eb0);
  sprintf(buf[8],"%3.7f",eb1);
  sprintf(buf[9],"%3.7f",lb0);
  sprintf(buf[10],"%3.7f",lb1);
  SetString(m_txt10,buf[7]);
  SetString(m_txt12,buf[8]);
  SetString(m_txt14,buf[9]);
  SetString(m_txt16,buf[10]);

}

/********************************************************************
  Method : Box2Data
  Returns : 1, error checking code removed for cross platform reasons
  Purpose : To store the data entered in the box in the global static
  parameters variable.
**********************************************************************/

int StatMetDiag::Box2Data(void)
{
  char temp[12];

  GetTextIn(m_Const,temp,11);
  myApp->StatMet.Constant = atof(temp);
  GetTextIn(m_CPU,temp,11);
  myApp->StatMet.CPUrate = atof(temp);
  GetTextIn(m_Size,temp,11);
  myApp->StatMet.Size = atof(temp);
  GetTextIn(m_Alpha,temp,11);
  myApp->StatMet.Alpha = atof(temp);
  GetTextIn(m_Time,temp,11);
  myApp->StatMet.Time = atof(temp); 
  GetTextIn(m_Srcobj,temp,11);
  myApp->StatMet.Instructions = atof(temp);
  myApp->StatMet.EstType = GetValue(m_EstType);

  myApp->StatMet.Structure = 1.0 + 0.4 * (float(GetValue(m_Struct)) / 100.0);
  
  switch(GetValue(m_Phase)) {
  case 0 :
    myApp->StatMet.Phase = 4.0;
    break;
  case 1 :
    myApp->StatMet.Phase = 2.5;
    break;
  case 2 :
    myApp->StatMet.Phase = 1.0;
    break;
  case 3 :
    myApp->StatMet.Phase = 0.35;
    break;
  }

  switch(GetValue(m_Team)) {
  case 0 :
    myApp->StatMet.Prog_Team = 0.4;
    break;
  case 1 :
    myApp->StatMet.Prog_Team = 1.0;
    break;
  case 2 :
    myApp->StatMet.Prog_Team = 2.5;
    break;
  }

  switch(GetValue(m_Mature)) {
  case 0 :
    myApp->StatMet.Maturity = 1.5;
    break;
  case 1 :
    myApp->StatMet.Maturity = 1.0;
    break;
  case 2 :
    myApp->StatMet.Maturity = 0.4;
    break;
  case 3 :
    myApp->StatMet.Maturity = 0.1;
    break;
  case 4 :
    myApp->StatMet.Maturity = 0.05;
    break;
  }
  return 1;
}






















